"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withClient = void 0;
const aws_profile_1 = require("./aws-profile");
const api_1 = require("./services/api");
const output_1 = require("./services/output");
class Client {
    constructor({ logLevel, apiService }) {
        this.logLevel = logLevel;
        this.output = new output_1.OutputService({ logLevel });
        if (apiService) {
            this.apiService = apiService;
        }
    }
}
const createClientMiddleware = (options) => async (argv) => {
    argv.client = new Client({
        logLevel: argv.logLevel,
    });
    if (options.withApiService) {
        const awsCredentialProvider = (0, aws_profile_1.awsProfileMiddleware)(argv);
        argv.client.apiService = (0, api_1.apiMiddleware)(argv, awsCredentialProvider);
    }
};
function withClient(command, description, builder, handler, options = {}) {
    const { withApiService = true } = options;
    return (yargs) => {
        const middleware = createClientMiddleware({
            withApiService,
        });
        const localBuilder = (localYargs) => {
            if (withApiService) {
                localYargs.options({
                    ...aws_profile_1.awsProfileMiddlewareOptions,
                    ...api_1.apiMiddlewareOptions,
                });
            }
            return builder(localYargs);
        };
        yargs.command(command, description, localBuilder, handler, [middleware]);
    };
}
exports.withClient = withClient;
