"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiMiddlewareOptions = exports.apiMiddleware = void 0;
const api_1 = require("../api");
const project_config_1 = require("../../../utils/project-config");
const errors_1 = require("../../../utils/errors");
function apiMiddleware(argv, awsCredentialProvider) {
    const projectConfig = (0, project_config_1.readProjectConfig)(argv.commandCwd);
    let endpoint;
    if (typeof argv.endpoint === 'string') {
        endpoint = argv.endpoint;
    }
    else if (projectConfig) {
        endpoint = projectConfig.apiEndpoint;
    }
    if (endpoint === undefined) {
        throw new errors_1.MissingApiEndpoint();
    }
    if (!projectConfig || projectConfig.apiEndpoint !== endpoint) {
        (0, project_config_1.writeProjectConfig)(argv.commandCwd, {
            apiEndpoint: endpoint,
        });
    }
    return new api_1.ApiService({
        awsCredentialProvider,
        apiEndpoint: endpoint,
    });
}
exports.apiMiddleware = apiMiddleware;
const apiMiddlewareOptions = {
    endpoint: {
        type: 'string',
        description: 'API endpoint to use.',
    },
};
exports.apiMiddlewareOptions = apiMiddlewareOptions;
