"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OutputService = void 0;
const chalk_1 = __importDefault(require("chalk"));
const strlen_1 = require("../../../utils/strlen");
const create_spinner_1 = require("./create-spinner");
class OutputService {
    constructor({ logLevel }) {
        this.log = (message, color = chalk_1.default.grey) => {
            this.print(message, color('> '));
        };
        this.debug = (message) => {
            if (this.isDebug) {
                this.print(chalk_1.default.gray(message), chalk_1.default.blueBright('debug '));
            }
        };
        this.error = (message) => {
            this.print(message, chalk_1.default.red('error '));
        };
        this.success = (message) => {
            this.print(message, chalk_1.default.green('success '));
        };
        this.spinner = (message, delay = 300) => {
            this.spinnerMessage = message;
            this._spinner = (0, create_spinner_1.createSpinner)(message, delay);
        };
        this.stopSpinner = () => {
            if (this._spinner) {
                this._spinner();
                this._spinner = null;
                this.spinnerMessage = '';
            }
        };
        this.spinnerMessage = '';
        this.logLevel = logLevel;
        this.isDebug = logLevel === 'verbose';
        this._spinner = null;
    }
    print(message, prefix) {
        const prefixLength = prefix ? (0, strlen_1.strlen)(prefix) : 0;
        const indentNewline = '\n' + ' '.repeat(prefixLength);
        this.stopSpinner();
        const indentedMessage = message.replace(/\n/, indentNewline);
        console.log((prefix || '') + indentedMessage);
    }
}
exports.OutputService = OutputService;
