"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAliasListCommand = void 0;
const chalk_1 = __importDefault(require("chalk"));
const ms_1 = __importDefault(require("ms"));
const text_table_1 = __importDefault(require("text-table"));
const client_1 = require("../../client");
const errors_1 = require("../../utils/errors");
const strlen_1 = require("../../utils/strlen");
async function aliasListCommand({ client, deploymentId, }) {
    const { apiService, output } = client;
    output.spinner(`Fetching aliases for deployment ${deploymentId}`);
    try {
        const aliases = await apiService.listAliases(deploymentId);
        output.stopSpinner();
        if (aliases.length === 0) {
            output.log(`No aliases linked to deployment ${deploymentId}\nCreate a new alias with the 'tf-next alias set' command.`);
            return;
        }
        output.log(`Linked aliases for deployment ${deploymentId}:\n`);
        const todayMillis = Date.now();
        console.log((0, text_table_1.default)([
            ['age ▼', 'alias'].map((header) => chalk_1.default.dim(header)),
            ...aliases.map((alias) => [
                (0, ms_1.default)(todayMillis - new Date(alias.createDate).getTime()),
                `https://${alias.id}`,
            ]),
        ], {
            hsep: ' '.repeat(3),
            stringLength: strlen_1.strlen,
        }).replace(/^/gm, '  ') + '\n');
    }
    catch (error) {
        if (error.code === 'DEPLOYMENT_NOT_FOUND') {
            throw new errors_1.DeploymentNotExists(deploymentId);
        }
        throw error;
    }
}
const createAliasListCommand = (0, client_1.withClient)('ls <deployment-id>', 'List aliases that are linked to a deployment', (yargs) => {
    return yargs.positional('deployment-id', {
        describe: 'ID of the deployment',
        type: 'string',
    });
}, ({ client, deploymentId }) => aliasListCommand({
    client,
    deploymentId,
}));
exports.createAliasListCommand = createAliasListCommand;
