"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAliasRemoveCommand = void 0;
const client_1 = require("../../client");
const errors_1 = require("../../utils/errors");
const trim_protocol_1 = require("../../utils/trim-protocol");
async function aliasRemoveCommand({ client, customDomain, }) {
    const { apiService, output } = client;
    const alias = (0, trim_protocol_1.trimProtocol)(customDomain);
    output.spinner('Removing alias');
    try {
        await apiService.deleteAlias(alias);
        output.success(`Alias ${alias} was removed.`);
    }
    catch (error) {
        if (error.code === 'ALIAS_NOT_FOUND') {
            throw new errors_1.AliasNotExists(alias);
        }
        if (error.code === 'DEPLOYMENT_ALIAS') {
            throw new errors_1.DeleteDeploymentAlias();
        }
        throw error;
    }
}
const createAliasRemoveCommand = (0, client_1.withClient)('rm <custom-domain>', 'Remove an existing alias', (yargs) => {
    yargs.positional('custom-domain', {
        describe: 'Domain of the alias',
        type: 'string',
    });
}, ({ client, customDomain }) => aliasRemoveCommand({
    client,
    customDomain,
}));
exports.createAliasRemoveCommand = createAliasRemoveCommand;
