"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAliasSetCommand = void 0;
const chalk_1 = __importDefault(require("chalk"));
const client_1 = require("../../client");
const errors_1 = require("../../utils/errors");
const trim_protocol_1 = require("../../utils/trim-protocol");
async function aliasSetCommand({ client, customDomain, target, override, }) {
    const { apiService, output } = client;
    const trimmedCustomDomain = (0, trim_protocol_1.trimProtocol)(customDomain);
    const trimmedTarget = (0, trim_protocol_1.trimProtocol)(target);
    output.spinner('Creating alias');
    try {
        const alias = await apiService.createAlias({
            alias: trimmedCustomDomain,
            target: trimmedTarget,
            override,
        });
        output.success(`Alias created: https://${alias.id}\n${chalk_1.default.gray `Now linked to deployment ${alias.deployment}`}`);
    }
    catch (error) {
        if (error.code === 'ALIAS_OVERRIDE_NOT_ALLOWED') {
            throw new errors_1.AliasOverrideNotAllowed(trimmedCustomDomain);
        }
        throw error;
    }
}
const createAliasSetCommand = (0, client_1.withClient)('set <custom-domain> <target>', 'Creates an alias that is linked to a deployment or another alias', (yargs) => {
    yargs
        .positional('custom-domain', {
        describe: 'Domain of the alias',
        type: 'string',
    })
        .positional('target', {
        describe: 'deployment-id or other alias',
        type: 'string',
    });
    yargs.options({
        force: {
            type: 'boolean',
            description: 'Override existing alias',
        },
    });
}, ({ client, customDomain, target, force }) => aliasSetCommand({
    client,
    customDomain,
    target,
    override: !!force,
}));
exports.createAliasSetCommand = createAliasSetCommand;
