"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBuildCommand = void 0;
const path = __importStar(require("path"));
const util = __importStar(require("util"));
const tf_next_runtime_1 = require("@millihq/tf-next-runtime");
const build_utils_1 = require("@vercel/build-utils");
const archiver_1 = __importDefault(require("archiver"));
const find_yarn_workspace_root_1 = __importDefault(require("find-yarn-workspace-root"));
const fs = __importStar(require("fs-extra"));
const tmp_1 = __importDefault(require("tmp"));
const utils_1 = require("../../utils");
const client_1 = require("../../client");
const TF_NEXT_VERSION = 1;
async function checkoutFiles(basePath, targetPath) {
    const files = await (0, build_utils_1.glob)('**', {
        cwd: basePath,
        ignore: [
            '**/node_modules/**',
            '**/.next/**',
            '**/.next-tf/**',
            '**/.git/**',
        ],
    });
    return (0, build_utils_1.download)(files, targetPath);
}
function normalizeRoute(input) {
    return input.replace(/\/index$/, '/');
}
async function writeOutput(props) {
    const lambdaDirPrefix = 'lambdas/';
    const staticDirPrefix = 'static/';
    const config = {
        lambdas: {},
        staticRoutes: [],
        lambdaRoutes: [],
        routes: props.routes,
        buildId: props.buildId,
        prerenders: props.prerenders,
        staticFilesArchive: 'static-website-files.zip',
        version: TF_NEXT_VERSION,
        images: props.images,
    };
    config.staticRoutes = Object.keys(props.staticWebsiteFiles)
        .map((fullFilePath) => fullFilePath.split(path.sep).join(path.posix.sep))
        .filter((fullFilePath) => !fullFilePath.startsWith('_next/static/'))
        .map((fullFilePath) => `/${fullFilePath}`);
    const outputFile = fs.createWriteStream(path.join(props.outputDir, 'deployment.zip'));
    const archive = (0, archiver_1.default)('zip', {
        zlib: { level: 5 },
    });
    await new Promise(async (resolve, reject) => {
        archive.pipe(outputFile);
        outputFile.on('close', function () {
            console.log(archive.pointer() + ' total bytes');
            resolve();
        });
        archive.on('error', (err) => {
            reject(err);
        });
        for (const [key, lambda] of Object.entries(props.lambdas)) {
            const zipFilename = `${key}.zip`;
            const route = `/${key}`;
            config.lambdaRoutes.push(route);
            config.lambdas[key] = {
                handler: lambda.handler,
                runtime: lambda.runtime,
                filename: zipFilename,
                route: normalizeRoute(route),
            };
            archive.append(lambda.zipBuffer, {
                name: lambdaDirPrefix + zipFilename,
            });
        }
        for (const [key, file] of Object.entries(props.staticWebsiteFiles)) {
            const buf = await (0, build_utils_1.streamToBuffer)(file.toStream());
            archive.append(buf, { name: `${staticDirPrefix}${key}` });
        }
        archive.append(JSON.stringify(config, null, 2), {
            name: 'config.json',
        });
        archive.finalize();
    });
}
async function buildCommand({ skipDownload = false, logLevel, deleteBuildCache = true, cwd, }) {
    let buildOutput = null;
    const mode = skipDownload ? 'local' : 'download';
    const tmpDir = mode === 'download'
        ? tmp_1.default.dirSync({ unsafeCleanup: deleteBuildCache })
        : null;
    const workspaceRoot = (0, find_yarn_workspace_root_1.default)(cwd);
    const repoRootPath = workspaceRoot ?? cwd;
    const relativeWorkPath = path.relative(repoRootPath, cwd);
    const workPath = mode === 'download' ? path.join(tmpDir.name, relativeWorkPath) : cwd;
    const outputDir = path.join(cwd, '.next-tf');
    fs.ensureDirSync(outputDir);
    if (mode === 'download') {
        console.log('Checking out files...');
        await checkoutFiles(repoRootPath, tmpDir.name);
    }
    try {
        const entrypoint = (0, utils_1.findEntryPoint)(workPath);
        const lambdas = {};
        const prerenders = {};
        const staticWebsiteFiles = {};
        const buildResult = await (0, tf_next_runtime_1.build)({
            files: {},
            workPath,
            repoRootPath: mode === 'download' ? tmpDir.name : repoRootPath,
            entrypoint,
            config: { sharedLambdas: true },
            meta: {
                isDev: false,
                skipDownload,
            },
        });
        const entryDirectory = path.dirname(entrypoint);
        const entryPath = path.join(workPath, entryDirectory);
        const buildId = await fs.readFile(path.join(entryPath, '.next', 'BUILD_ID'), 'utf8');
        for (const [key, file] of Object.entries(buildResult.output)) {
            switch (file.type) {
                case 'Lambda': {
                    lambdas[key] = file;
                    break;
                }
                case 'Prerender': {
                    prerenders[key] = file;
                    break;
                }
                case 'FileFsRef': {
                    staticWebsiteFiles[key] = file;
                    break;
                }
            }
        }
        const prerenderedOutput = {};
        for (const [key, prerender] of Object.entries(prerenders)) {
            const match = Object.entries(lambdas).find(([, lambda]) => {
                return lambda === prerender.lambda;
            });
            if (match) {
                const [lambdaKey] = match;
                prerenderedOutput[`/${key}`] = { lambda: lambdaKey };
            }
        }
        buildOutput = {
            buildId,
            prerenders: prerenderedOutput,
            routes: buildResult.routes,
            lambdas,
            staticWebsiteFiles,
            outputDir: outputDir,
            images: buildResult.images,
        };
        await writeOutput(buildOutput);
        if (logLevel === 'verbose') {
            console.log(util.format('Routes:\n%s', JSON.stringify(buildResult.routes, null, 2)));
        }
        console.log('Build successful!');
    }
    catch (err) {
        console.log('Build failed:');
        console.error(err);
        process.exitCode = 1;
    }
    if (tmpDir && deleteBuildCache) {
        tmpDir.removeCallback();
    }
    return buildOutput;
}
const createBuildCommand = (0, client_1.withClient)('build', 'Build a project', (yargs) => {
    yargs.option('skip-download', {
        type: 'boolean',
        description: 'Runs the build in the current working directory.',
    });
}, async ({ commandCwd, logLevel, skipDownload }) => {
    await buildCommand({
        cwd: commandCwd,
        logLevel,
        skipDownload,
    });
}, {
    withApiService: false,
});
exports.createBuildCommand = createBuildCommand;
