"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDeploymentListCommand = void 0;
const chalk_1 = __importDefault(require("chalk"));
const ms_1 = __importDefault(require("ms"));
const text_table_1 = __importDefault(require("text-table"));
const client_1 = require("../../client");
const strlen_1 = require("../../utils/strlen");
function renderStatus(status) {
    switch (status) {
        case 'FINISHED':
            return chalk_1.default.green `ready`;
        case 'INITIALIZED':
            return chalk_1.default.gray `init`;
        case 'CREATE_FAILED':
        case 'DESTROY_FAILED':
            return chalk_1.default.red `error`;
        case 'CREATE_IN_PROGRESS':
            return chalk_1.default.cyan `creating`;
        case 'DESTROY_IN_PROGRESS':
            return chalk_1.default.cyan `destroying`;
    }
    return status;
}
async function deploymentListCommand({ client }) {
    const { apiService, output } = client;
    output.spinner('Fetching deployments');
    const deployments = await apiService.listDeployments();
    output.stopSpinner();
    if (deployments.length === 0) {
        output.log(`No deployments created yet.\n${chalk_1.default.gray('Create a new deployment by running `tf-next deploy`.')}`);
        return;
    }
    const todayMillis = Date.now();
    console.log((0, text_table_1.default)([
        ['age ▼', 'deployment-id', 'status'].map((header) => chalk_1.default.dim(header)),
        ...deployments.map((deployment) => [
            (0, ms_1.default)(todayMillis - new Date(deployment.createDate).getTime()),
            deployment.id,
            renderStatus(deployment.status),
        ]),
    ], {
        hsep: ' '.repeat(3),
        stringLength: strlen_1.strlen,
    }).replace(/^/gm, '  ') + '\n');
}
const createDeploymentListCommand = (0, client_1.withClient)('ls', 'List the latest deployments', async () => { }, async ({ client }) => {
    await deploymentListCommand({
        client,
    });
});
exports.createDeploymentListCommand = createDeploymentListCommand;
