"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDeploymentRemoveCommand = void 0;
const client_1 = require("../../client");
const errors_1 = require("../../utils/errors");
async function deploymentRemoveCommand({ client, deploymentId, }) {
    const { apiService, output } = client;
    output.spinner(`Removing deployment ${deploymentId}`);
    try {
        const result = await apiService.deleteDeploymentById(deploymentId);
        if (result &&
            (result.status === 'DESTROY_REQUESTED' ||
                result.status === 'DESTROY_IN_PROGRESS')) {
            try {
                await apiService.pollForDeploymentStatus(deploymentId, 'FINISHED');
            }
            catch (error) {
                if (error.code !== 'DEPLOYMENT_NOT_FOUND') {
                    throw error;
                }
            }
        }
        output.success('Deployment successfully removed.');
    }
    catch (error) {
        switch (error.code) {
            case 'NOT_FOUND':
                throw new errors_1.DeploymentNotExists(deploymentId);
            case 'ALIASES_ASSOCIATED':
                throw new errors_1.DeploymentHasLinkedAliases();
            default:
                throw error;
        }
    }
}
const createDeploymentRemoveCommand = (0, client_1.withClient)('rm <deployment-id>', 'Remove a deployment', (yargs) => {
    yargs.positional('deployment-id', {
        describe: 'ID of the deployment that should be removed.',
        type: 'string',
    });
}, async ({ client, deploymentId }) => {
    await deploymentRemoveCommand({
        client,
        deploymentId,
    });
});
exports.createDeploymentRemoveCommand = createDeploymentRemoveCommand;
