"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const main_1 = require("./commands/main");
const errors_1 = require("./utils/errors");
async function runCli() {
    let errorCaught = false;
    try {
        await (0, main_1.createMainCommand)(yargs_1.default).parseAsync(process.argv.slice(2), {}, (error, argv, output) => {
            const client = argv.client;
            if (client) {
                client.output.stopSpinner();
            }
            if (error instanceof errors_1.CliError) {
                if (!client) {
                    throw new Error('Client was not initialized');
                }
                const { output } = client;
                output.error(error.message);
                errorCaught = true;
                process.exitCode = 1;
            }
            else if (error instanceof errors_1.ResponseError) {
                const client = argv.client;
                if (!client) {
                    throw new Error('Client was not initialized');
                }
                const { output } = client;
                if (error.serverMessage) {
                    output.debug(`ServerMessage: ${error.serverMessage}`);
                }
                output.error(error.message);
                errorCaught = true;
                process.exitCode = 1;
            }
            else {
                if (output) {
                    console.log(output);
                }
                else if (error) {
                    console.error(error);
                }
            }
        });
    }
    catch (potentiallyUncaughtError) {
        if (!errorCaught) {
            process.exitCode = 1;
            console.error(potentiallyUncaughtError);
        }
    }
}
runCli();
