"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeploymentCreateFailed = exports.DeploymentHasLinkedAliases = exports.DeploymentNotExists = exports.DeleteDeploymentAlias = exports.AliasNotExists = exports.AliasOverrideNotAllowed = exports.CredentialsError = exports.MissingApiEndpoint = void 0;
const cli_error_1 = require("./cli-error");
class MissingApiEndpoint extends cli_error_1.CliError {
    constructor() {
        super({
            code: 'MISSING_API_ENDPOINT',
            message: 'API endpoint not set. Please use the --endpoint flag to set the endpoint.',
        });
    }
}
exports.MissingApiEndpoint = MissingApiEndpoint;
class CredentialsError extends cli_error_1.CliError {
    constructor() {
        super({
            code: 'INVALID_CREDENTIALS',
            message: 'Could not read the provided AWS credentials.\nPlease make sure that the provided AWS profile exists.',
        });
    }
}
exports.CredentialsError = CredentialsError;
class AliasOverrideNotAllowed extends cli_error_1.CliError {
    constructor(alias) {
        super({
            code: 'ALIAS_OVERRIDE_NOT_ALLOWED',
            message: `Alias ${alias} already exists.\nTo override run the command with --force flag.`,
        });
    }
}
exports.AliasOverrideNotAllowed = AliasOverrideNotAllowed;
class AliasNotExists extends cli_error_1.CliError {
    constructor(alias) {
        super({
            code: 'ALIAS_NOT_EXISTS',
            message: `Alias with name ${alias} does not exist.`,
        });
    }
}
exports.AliasNotExists = AliasNotExists;
class DeleteDeploymentAlias extends cli_error_1.CliError {
    constructor() {
        super({
            code: 'ALIAS_DELETE_DEPLOYMENT_ALIAS',
            message: 'Requested alias is a deployment alias.\nCan only be removed when the linked deployment is removed.',
        });
    }
}
exports.DeleteDeploymentAlias = DeleteDeploymentAlias;
class DeploymentNotExists extends cli_error_1.CliError {
    constructor(deploymentId) {
        super({
            code: 'DEPLOYMENT_NOT_EXISTS',
            message: `Deployment with id ${deploymentId} does not exist.`,
        });
    }
}
exports.DeploymentNotExists = DeploymentNotExists;
class DeploymentHasLinkedAliases extends cli_error_1.CliError {
    constructor() {
        super({
            code: 'DEPLOYMENT_HAS_CUSTOM_ALIASES',
            message: 'Deployment has linked custom alias(es).\nPlease remove all custom aliases before removing a deployment.',
        });
    }
}
exports.DeploymentHasLinkedAliases = DeploymentHasLinkedAliases;
class DeploymentCreateFailed extends cli_error_1.CliError {
    constructor() {
        super({
            code: 'DEPLOYMENT_CREATE_FAILED',
            message: 'Creation of the deployment failed. Please see the logs in AWS CloudWatch for more information.',
        });
    }
}
exports.DeploymentCreateFailed = DeploymentCreateFailed;
