"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResponseError = exports.createResponseError = void 0;
class ResponseError extends Error {
    constructor({ status, code, message, serverMessage }) {
        super(message);
        this.status = status;
        this.code = code;
        this.serverMessage = serverMessage;
    }
}
exports.ResponseError = ResponseError;
async function createResponseError(res) {
    let errorBody = {};
    if (res.headers.get('content-type') === 'application/json') {
        try {
            errorBody = await res.json();
        }
        catch (_ignoredError) { }
    }
    const status = typeof errorBody.status === 'number' ? errorBody.status : res.status;
    const code = typeof errorBody.code === 'string' ? errorBody.code : '';
    const message = typeof errorBody.message === 'string' ? errorBody.message : '';
    if (res.status === 403) {
        return new ResponseError({
            status: 403,
            code: 'PERMISSION_ERROR',
            serverMessage: message,
            message: 'Authentication failed.\nMake sure that the AWS user has the correct permissions.',
        });
    }
    return new ResponseError({
        status,
        code,
        message,
    });
}
exports.createResponseError = createResponseError;
