"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeProjectConfig = exports.readProjectConfig = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const ajv_1 = __importDefault(require("ajv"));
const CONFIG_DIR = '.next-tf';
const CONFIG_DIR_PROJECT_FILE = 'project.json';
const projectSchema = {
    type: 'object',
    properties: {
        apiEndpoint: {
            type: 'string',
            minLength: 1,
        },
    },
    required: ['apiEndpoint'],
};
function readProjectConfig(cwd) {
    const configPath = (0, path_1.join)(cwd, CONFIG_DIR, CONFIG_DIR_PROJECT_FILE);
    const configExists = (0, fs_1.existsSync)(configPath);
    if (configExists) {
        try {
            const projectFileRaw = (0, fs_1.readFileSync)(configPath, 'utf-8');
            const projectFileContent = JSON.parse(projectFileRaw);
            const ajv = new ajv_1.default();
            const validate = ajv.compile(projectSchema);
            if (validate(projectFileContent)) {
                return projectFileContent;
            }
            return null;
        }
        catch (error) {
            return null;
        }
    }
    return null;
}
exports.readProjectConfig = readProjectConfig;
function writeProjectConfig(cwd, projectConfig) {
    const configPath = (0, path_1.join)(cwd, CONFIG_DIR, CONFIG_DIR_PROJECT_FILE);
    (0, fs_1.writeFileSync)(configPath, JSON.stringify(projectConfig, null, 2));
}
exports.writeProjectConfig = writeProjectConfig;
